#!/bin/sh

# find out where Moonlight|3D is installed
SCRIPT_NAME=$_ # note that this must be the first line in the script

READLINK=`readlink $SCRIPT_NAME`

# if the script was called using a symlink, use symlink destination
if test -n $READLINE ; then
  SCRIPT_NAME=$READLINK
fi

# test for leading / to see if path is absolute. if not, append to $PWD
case $SCRIPT_NAME in
  /*) # absolute path, do nothing
  ;;
  *)
    SCRIPT_NAME="$PWD/$SCRIPT_NAME" ;;
esac

MOONLIGHT_BASE=$SCRIPT_NAME

# try to determine the platform
case `uname` in
"Linux")
	MOONLIGHT_PLATFORM=Linux
	MOONLIGHT_ARCH=`uname -m`
;;
"Darwin")
	MOONLIGHT_PLATFORM=Darwin
	# on Darwin there are universal binaries for PPC and Intel
	MOONLIGHT_ARCH=universal
;;
"SunOS") # TODO: verify this uname string
	MOONLIGHT_PLATFORM=SunOS
	MOONLIGHT_ARCH=`uname -p`
;;
*)
	echo "Unknown or unsupported platform. Moonlight|3D will attempt to start, but may fail."
	MOONLIGHT_PLATFORM=Unknown
	MOONLIGHT_ARCH=Unknown
;;
esac

# set up some environment variables

MOONLIGHT_LIB=$MOONLIGHT_BASE/lib/$MOONLIGHT_PLATFORM/$MOONLIGHT_ARCH

export LD_LIBRARY_PATH=$MOONLIGHT_LIB:$LD_LIBRARY_PATH

for i in $MOONLIGHT_BASE/lib/jar/*.jar ; do
  CLASSPATH=$i:$CLASSPATH
done

for i in $MOONLIGHT_LIB/*.jar ; do
  CLASSPATH=$i:$CLASSPATH
done

echo CLASSPATH=$CLASSPATH
echo LD_LIBRARY_PATH=$LD_LIBRARY_PATH

# we don't supply the class path using a manifest because Jython won't find
# the additions jars then
# pass $MOONLIGHT_BASE on to program
java -server -Dcom.trolltech.qt.library-path=$MOONLIGHT_LIB -Xmx1024m -cp $CLASSPATH:mlminimal.jar eu.moonlight3d.minimal.Minimal $MOONLIGHT_BASE
